=======
Credits
=======

The Yarely project is an output of the e-Campus team at `Lancaster University`_.

Significant portions of Yarely were initially developed as part of `Dr. Sarah Clinch’s EPSRC-funded PhD`_, supervised by `Prof. Nigel Davies`_ (awarded by Lancaster University in 2014).

.. _Lancaster University:
.. _Dr. Sarah Clinch’s EPSRC-funded PhD: http://eprints.lancs.ac.uk/70431/1/thesis.pdf
.. _Prof. Nigel Davies: http://www.lancaster.ac.uk/scc/about-us/people/nigel-davies


Maintainers
------------------------
* Sarah Clinch <seclinch@gmail.com>
* Mateusz Mikusz <m.mikusz@lancaster.ac.uk>


Contributors
------------------------

* Sarah Clinch <seclinch@gmail.com>
* Nigel Davies <n.a.davies@lancaster.ac.uk>
* Adrian Friday <a.friday@lancaster.ac.uk>
* Mateusz Mikusz <m.mikusz@lancaster.ac.uk>
* Peter Shaw <p.shaw@lancaster.ac.uk>
* Graham Clinch <g.clinch@lancaster.ac.uk>
* Bholanathsingh Surajbali <surajbali@gmail.com>


Financial Support
------------------------

This software was developed (and is maintained) as part of ongoing research into open digital signage within the context of the Lancaster University e-Campus display network. This research was made possible through the financial support of a number of funding bodies.

Research leading to this software was partially funded through:

* an EPSRC studentship
* the European Union Seventh Framework Programme under FET grant numbers 244011 (`PD-NET <http://pd-net.org>`_) and 612933 (`RECALL <http://recall-fet.eu>`_)
* the UK EPSRC as part of `"PACTMAN: Trust, Privacy and Consent in Future Pervasive Environments" <http://pactman.uk>`_ (EP/N028228/1) and `"PETRAS IoT Research Hub – Cybersecurity of the Internet of Things" <http://petrashub.org>`_ (EP/N023234/1).
* a Google Faculty Research Award and Google Cloud Credits Award
